All files in this directory ara maintained inside the the `mara_app` package ([https://github.com/mara/mara-app/blob/master/.scripts/](https://github.com/mara/mara-app/blob/master/.scripts/)) and automatically synced to project code.
